@@ -1637,7 +1637,7 @@ class Drone:
 
 
 
-    def send_display_draw_string_align(self, x_start, x_end, y, message, align = DisplayAlign.Center, font = DisplayFont.LIBERATION_MONO_5X8, pixel = DisplayPixel.WHITE):
+    def send_display_draw_string_align(self, x_start, x_end, y, message, align = DisplayAlign.CENTER, font = DisplayFont.LIBERATION_MONO_5X8, pixel = DisplayPixel.WHITE):
         
         if ( (not isinstance(align, DisplayAlign)) or (not isinstance(font, DisplayFont)) or (not isinstance(pixel, DisplayPixel)) or (not isinstance(message, str)) ):
             return None
